module.exports = defineTest({
	description: 'calls non-function default exports'
});
